@@ -16,18 +16,70 @@ Font-Awesome and other iconic fonts for PyQt / PySide applications.
    set_defaults
 """
 
+import hashlib
+import os
+
 # Third party imports
 from qtpy import QtCore, QtWidgets, QtGui
 
 # Local imports
 from ._version import __version__, version_info
 from .animation import Pulse, Spin
-from .iconic_font import IconicFont, set_global_defaults
+from .iconic_font import IconicFont, set_global_defaults, FontError
+from .iconic_font import SYSTEM_FONTS as _SYSTEM_FONTS
 from .styles import dark, light
 
 # Constants
 _resource = { 'iconic': None }
 
+_BUNDLED_FONTS = (
+    ('fa',
+        'fontawesome4-webfont-4.7.ttf',
+        'fontawesome4-webfont-charmap-4.7.json'),
+    ('fa5',
+        'fontawesome5-regular-webfont-5.15.4.ttf',
+        'fontawesome5-regular-webfont-charmap-5.15.4.json'),
+    ('fa5s',
+        'fontawesome5-solid-webfont-5.15.4.ttf',
+        'fontawesome5-solid-webfont-charmap-5.15.4.json'),
+    ('fa5b',
+        'fontawesome5-brands-webfont-5.15.4.ttf',
+        'fontawesome5-brands-webfont-charmap-5.15.4.json'),
+    ('ei',
+        'elusiveicons-webfont-2.0.ttf',
+        'elusiveicons-webfont-charmap-2.0.json'),
+    ('mdi',
+        'materialdesignicons5-webfont-5.9.55.ttf',
+        'materialdesignicons5-webfont-charmap-5.9.55.json'),
+    ('mdi6',
+        'materialdesignicons6-webfont-6.9.96.ttf',
+        'materialdesignicons6-webfont-charmap-6.9.96.json'),
+    ('ph',
+        'phosphor-1.3.0.ttf',
+        'phosphor-charmap-1.3.0.json'),
+    ('ri',
+        'remixicon-2.5.0.ttf',
+        'remixicon-charmap-2.5.0.json'),
+    ('msc',
+        'codicon-0.0.35.ttf',
+        'codicon-charmap-0.0.35.json'),
+)
+
+
+# MD5 Hashes for font files bundled with qtawesome:
+_MD5_HASHES = {
+    'fontawesome4-webfont-4.7.ttf': 'b06871f281fee6b241d60582ae9369b9',
+    'fontawesome5-regular-webfont-5.15.4.ttf': 'dc47e4089f5bcb25f241bdeb2de0fb58',
+    'fontawesome5-solid-webfont-5.15.4.ttf': '5de19800fc9ae73438c2e5c61d041b48',
+    'fontawesome5-brands-webfont-5.15.4.ttf': '513aa607d398efaccc559916c3431403',
+    'elusiveicons-webfont-2.0.ttf': '207966b04c032d5b873fd595a211582e',
+    'materialdesignicons5-webfont-5.9.55.ttf': 'b7d40e7ef80c1d4af6d94902af66e524',
+    'materialdesignicons6-webfont-6.9.96.ttf': 'ecaabfbb23fdac4ddbaf897b97257a92',
+    'phosphor-1.3.0.ttf': '5b8dc57388b2d86243566b996cc3a789',
+    'remixicon-2.5.0.ttf': '888e61f04316f10bddfff7bee10c6dd0',
+    'codicon-0.0.35.ttf': '8478f5b3df2158f7e4864473e34efda1',
+}
+
 
 def has_valid_font_ids(inst):
     """Validate instance's font ids are loaded to QFontDatabase.
@@ -60,28 +112,22 @@ def _instance():
         _resource['iconic'] = None
 
     if _resource['iconic'] is None:
-        _resource['iconic'] = IconicFont(
-            ('fa',
-             'fontawesome4.7-webfont.ttf',
-             'fontawesome4.7-webfont-charmap.json'),
-            ('fa5',
-             'fontawesome5-regular-webfont.ttf',
-             'fontawesome5-regular-webfont-charmap.json'),
-            ('fa5s',
-             'fontawesome5-solid-webfont.ttf',
-             'fontawesome5-solid-webfont-charmap.json'),
-            ('fa5b',
-             'fontawesome5-brands-webfont.ttf',
-             'fontawesome5-brands-webfont-charmap.json'),
-            ('ei', 'elusiveicons-webfont.ttf', 'elusiveicons-webfont-charmap.json'),
-            ('mdi', 'materialdesignicons5-webfont.ttf',
-             'materialdesignicons5-webfont-charmap.json'),
-            ('mdi6', 'materialdesignicons6-webfont.ttf',
-             'materialdesignicons6-webfont-charmap.json'),
-            ('ph', 'phosphor.ttf', 'phosphor-charmap.json'),
-            ('ri', 'remixicon.ttf', 'remixicon-charmap.json'),
-            ('msc', 'codicon.ttf', 'codicon-charmap.json'),
-        )
+        # Verify that vendorized fonts are not corrupt
+        if not _SYSTEM_FONTS:
+            for fargs in _BUNDLED_FONTS:
+                ttf_filename = fargs[1]
+                ttf_hash = _MD5_HASHES.get(ttf_filename, None)
+                if ttf_hash is None:
+                    continue
+                ttf_filepath = os.path.join(
+                    os.path.dirname(os.path.realpath(__file__)),
+                    "fonts", ttf_filename)
+                with open(ttf_filepath, "rb") as f:
+                    ttf_calculated_hash_code = hashlib.md5(f.read()).hexdigest()
+                if ttf_calculated_hash_code != ttf_hash:
+                    raise FontError(f"Font is corrupt at: '{ttf_filepath}'")
+
+        _resource['iconic'] = IconicFont(*_BUNDLED_FONTS)
     return _resource['iconic']
 
 
@@ -192,7 +238,8 @@ def load_font(prefix, ttf_filename, charmap_filename, directory=None):
     """
     Loads a font file and the associated charmap.
 
-    If ``directory`` is None, the files will be looked for in ``./fonts/``.
+    If ``directory`` is passed, the files will be looked for in the qtawesome
+    ``fonts`` directory.
 
     Parameters
     ----------
@@ -203,14 +250,31 @@ def load_font(prefix, ttf_filename, charmap_filename, directory=None):
     charmap_filename: str
         Character map filename
     directory: str or None, optional
-        Directory for font and charmap files
+        Directory path for font and charmap files
 
     Example
     -------
-    The spyder ide uses qtawesome and uses a custom font for spyder-specific
-    icons::
+    If you want to load a font ``myicon.tff`` with a ``myicon-charmap.json``
+    charmap added to the qtawesome ``fonts`` directory (usually located at
+    ``</path/to/lib/python>/site-packages/qtawesome/fonts/``) you can use::
 
-        qta.load_font('spyder', 'spyder.ttf', 'spyder-charmap.json')
+        qta.load_font(
+            'myicon',
+            'myicon.ttf',
+            'myicon-charmap.json'
+        )
+
+    However, if you want to load a font ``myicon.tff`` with a
+    ``myicon-charmap.json`` charmap located in a specific path outside the
+    qtawesome ``font`` directory like for example ``/path/to/myproject/fonts``
+    you can use::
+
+        qta.load_font(
+            'myicon',
+            'myicon.ttf',
+            'myicon-charmap.json',
+            directory='/path/to/myproject/fonts'
+        )
 
     """
     return _instance().load_font(prefix, ttf_filename, charmap_filename, directory)
@@ -270,19 +334,23 @@ class IconWidget(QtWidgets.QLabel):
     """
     IconWidget gives the ability to display an icon as a widget
 
-    if supports the same arguments as icon()
-    for example
-    music_icon = qta.IconWidget('fa5s.music',
-                                color='blue',
-                                color_active='orange')
+    It supports the same arguments as `icon()`,
+    for example,
 
-    it also have setIcon() and setIconSize() functions
+        music_icon = qta.IconWidget('fa5s.music',
+                                    color='blue',
+                                    color_active='orange')
+
+    The exceptions are `parent` and `size` keyword-only arguments,
+    which allow setting the widget parent and initial size, correspondingly.
+
+    It also has `setIcon()` and `setIconSize()` functions.
     """
 
     def __init__(self, *names, **kwargs):
         super().__init__(parent=kwargs.get('parent'))
         self._icon = None
-        self._size = QtCore.QSize(16, 16)
+        self._size = kwargs.get('size', QtCore.QSize(16, 16))
         self.setIcon(icon(*names, **kwargs))
 
     def setIcon(self, _icon):
